AndroidCallKitSettings class

A configuration model for managing Android CallKit behavior.

Use this class to specify whether the ringtone and incoming call UI should be enabled.

Constructors

AndroidCallKitSettings({bool enableRingtone = true, bool enableIncomingCallUI = true})
Creates a new instance of AndroidCallKitSettings.

Properties

enableIncomingCallUI → bool
Whether the default Android incoming call UI should be shown. Defaults to true.
final
enableRingtone → bool
Whether the ringtone should be played for incoming calls. Defaults to true.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the current settings to a Map for platform channel use.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited