FlyChatFlutterPlatform class abstract

An abstract base class for the FlyChat platform interface.

This class serves as a contract for the implementation of the MirrorFly functionality across different platforms. It defines a set of methods that platform-specific implementations of MirrorFly must provide. This ensures a consistent API surface for the higher-level Dart code that interacts with these platform-specific implementations.

The class extends PlatformInterface, leveraging the token verification mechanism to ensure that a proper subclass is provided as the implementation.

Usage: Implementations should override the methods defined in this class to provide platform-specific behavior. The static instance field should be set to the platform-specific implementation of FlyChatFlutterPlatform that is being used.

Inheritance
  • Object
  • PlatformInterface
  • FlyChatFlutterPlatform
Implementers

Constructors

FlyChatFlutterPlatform()
Constructs a FlyChatFlutterPlatform.

Properties

blockedThisUser → Stream
Stream that emits events when user is blocked.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isSDKInitialized → bool
isSDKInitialized is used to check whether the sdk isInitialized or not.
no setter
myProfileUpdated → Stream
Stream that emits events when the current user profile is updated.
no setter
onAdminBlockedOtherUser → Stream
Stream that emits events when the admin blocks another user.
no setter
onAdminBlockedUser → Stream
Stream that emits events when the current user is blocked by admin.
no setter
onAllChatsCleared → Stream
Stream that emits events when a all chats is cleared
no setter
onArchivedSettingsUpdated → Stream
Stream that emits events when Archived/Unarchive settings is toggled
no setter
onArchiveUnArchiveChats → Stream
Stream that emits events when chat is Archived/Unarchived
no setter
onAvailableFeaturesUpdated → Stream
Stream that emits events when the available features are updated.
no setter
onBackupFailure → Stream
Stream that emits events when a backup is failed.
no setter
onBackupProgressChanged → Stream
Stream that emits events when a backup is progress changes.
no setter
onBackupSuccess → Stream
Stream that emits events when a backup is completed successfully.
no setter
onCallAction → Stream
Stream that emits events when the call action is performed.
no setter
onCallLogDeleted → Stream
Stream that emits events when the call log is deleted.
no setter
onCallLogsUpdated → Stream
Stream that emits events when the call logs are updated.
no setter
onCallStatusUpdated → Stream
Stream that emits events when the call status is updated.
no setter
onChatCleared → Stream
Stream that emits events when a chat is cleared.
no setter
onChatMuteStatusUpdated → Stream
Stream that emits events when a chat is mute/un-muted
no setter
onChatTypingStatus → Stream
Stream that emits events when the user is typing in a single chat.
no setter
onClearAllCallLog → Stream
Stream that emits events when the call log is cleared.
no setter
onConnected → Stream
Stream that emits events when the server connection is connected.
no setter
onConnectionFailed → Stream
Stream that emits events when the server connection is failed.
no setter
onContactSyncComplete → Stream
Stream that emits events when the contact sync is completed.
no setter
onDisconnected → Stream
Stream that emits events when the server connection is disconnected.
no setter
onError → Stream
Stream that emits events when the call link subscribe error
no setter
onFetchingGroupMembersCompleted → Stream
Stream that emits events when members are fetched from a group.
no setter
onGroupDeletedLocally → Stream
Stream that emits events when a group is deleted locally.
no setter
onGroupNotificationMessage → Stream
Stream that emits events when a message is received in a group.
no setter
onGroupProfileFetched → Stream
Stream that emits events when a group message is fetched.
no setter
onGroupProfileUpdated → Stream
Stream that emits events when a group profile is updated.
no setter
onGroupTypingStatus → Stream
Stream that emits events when the user is typing in a group chat.
no setter
onIncomingCallReceived → Stream
Stream that emits events when the incoming call is arrived
no setter
onLeftFromGroup → Stream
Stream that emits events when a user leaves a group.
no setter
onLocalVideoTrackAdded → Stream
Stream that emits events when the video call is connected and the local video track is added.
no setter
onLoggedOut → Stream
Stream that emits events when the current user is logged out of the SDK.
no setter
onMediaStatusUpdated → Stream
Stream that emits events when a media status is updated.
no setter
onMemberMadeAsAdmin → Stream
Stream that emits events when a member is made an admin in a group.
no setter
onMemberRemovedAsAdmin → Stream
Stream that emits events when a member is removed as an admin in a group.
no setter
onMemberRemovedFromGroup → Stream
Stream that emits events when a member is removed from a group.
no setter
onMessageDeleted → Stream
Stream that emits events when a message is deleted
no setter
onMessageEdited → Stream
Stream that emits events when a message is edited.
no setter
onMessageReceived → Stream
Stream that emits events when a message is received.
no setter
onMessageStatusUpdated → Stream
Stream that emits events when a message status is updated.
no setter
onMissedCall → Stream
Stream that emits events when the call is missed / not answered.
no setter
onMuteStatusUpdated → Stream
Stream that emits events when the users in call are muted or un-muted.
no setter
onNewGroupCreated → Stream
Stream that emits events when a new group is created.
no setter
onNewMemberAddedToGroup → Stream
Stream that emits events when new members are added to a group.
no setter
onReconnecting → Stream
Stream that emits events when the server is reconnecting.
no setter
onRemoteVideoTrackAdded → Stream
Stream that emits events when the video call is connected and the remote video track is added.
no setter
onRestoreFailure → Stream
Stream that emits events when a restore is failed.
no setter
onRestoreProgressChanged → Stream
Stream that emits events when a backup is progress changes.
no setter
onRestoreSuccess → Stream
Stream that emits events when a restore is completed successfully.
no setter
onSubscribeSuccess → Stream
Stream that emits events when the call link subscribed success.
no setter
onSuperAdminDeleteGroup → Stream
Stream that emits events when Super Admin deletes the Group
no setter
onTrackAdded → Stream
Stream that emits events when the call is connected and the track (local and remote video) tracks is added.
no setter
onUpdateFavourites → Stream
Stream that emits events when a message favourites has been updated
no setter
onUpdateMuteSettings → Stream
Stream that emits events when a mute/un-mute setting is updated
no setter
onUploadDownloadProgressChanged → Stream
Stream that emits events when a upload/ downlaod progress is changed.
no setter
onUserSpeaking → Stream
Stream that emits events when the user in call is speaking.
no setter
onUserStoppedSpeaking → Stream
Stream that emits events when the user in call stops speaking.
no setter
onUsersUpdated → Stream
Stream that emits events when the call link users are updated
no setter
onWebLogout → Stream
Stream that emits events when a corresponding web login is logged out
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setTypingStatus → Stream
Stream that emits events when the user is typing.
no setter
showOrUpdateOrCancelNotification → Stream
Stream that emits events when notification is needed to be shown or updated or cancelled.
no setter
unblockedThisUser → Stream
Stream that emits events when the user is unblocked.
no setter
userBlockedMe → Stream
Stream that emits events when the current user is blocked by another user.
no setter
userCameOnline → Stream
Stream that emits events when the user came online.
no setter
userDeletedHisProfile → Stream
Stream that emits events when the user deleted his profile.
no setter
userProfileFetched → Stream
Stream that emits events when the user profile is updated.
no setter
usersIBlockedListFetched → Stream
Stream that emits events when the user i blocked list is fetched.
no setter
usersProfilesFetched → Stream
Stream that emits events when the user's profile is fetched.
no setter
usersWhoBlockedMeListFetched → Stream
Stream that emits events when the user who blocked me list is fetched.
no setter
userUnBlockedMe → Stream
Stream that emits events when the user unblocks current user.
no setter
userUpdatedHisProfile → Stream
Stream that emits events when the user updated his profile.
no setter
userWentOffline → Stream
Stream that emits events when the user went offline.
no setter

Methods

acceptVideoCallSwitchRequest() → Future<bool>
This method is used to accept the video call switch request.
addContact(String number, String name) → Future<bool?>
This method is used to add the contact.
addUsersToGroup(String jid, List<String> userList, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to add the members to the group.
answerCall({required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to answer the call
appLaunchedFromMissedCall() → Future<bool?>
This method is used to get whether the app is launched from missed call.
authToken() → Future<String?>
This method is used to get the Authentication Token.
blockUser(String userJID, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to block the user.
cancelBackup() → Future<void>
This method is used to cancel the backup started.
cancelMediaUploadOrDownload(String messageId) → dynamic
This method is used to cancel the media upload or download.
cancelRestore() → Future<void>
This method is used to cancel the restore started.
cancelVideoCallSwitch() → Future<bool>
This method is used to cancel the video call switch.
clearAllConversation(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to clear all the conversation.
clearChat(String jid, String chatType, bool clearExceptStarred, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to clear the chat of a user using JID.
configureAndroidCallKit(AndroidCallKitSettings builder) → Future<bool?>
Configures the Android CallKit settings such as ringtone and UI visibility.
contactSyncStateValue() → Future<bool>
Queries the current contact sync state.
copyTextMessages(List<String> messageIds) → dynamic
This method is used to copy the text messages.
createGroup(String groupName, List<String> userJidList, String imageFilePath, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to create the group.
This method is used to create the meet link.
createOfflineGroupInOnline(String groupId) → Future<bool?>
This method is used to get create the group in offline
createTopic({required String topicName, List<TopicMetaData> metaData = const [], dynamic callback(FlyResponse response)?}) → Future<void>
This method is used to create the topic.
declineCall() → Future<bool?>
This method is used to decline the call.
declineVideoCallSwitchRequest() → Future<bool>
This method is used to decline the video call switch request.
deleteAccount(String reason, String? feedback, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the account.
deleteAllMessages() → dynamic
This method is used to delete all the messages.
deleteBusyStatus(String id, String status, bool isCurrentStatus) → Future<bool?>
Deletes a busy status.
deleteCallLog(List<String> jidlist, bool isClearAll, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the call log from the list.
deleteGroup(String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the group.
deleteMessagesForEveryone(String jid, String chatType, List<String> messageIds, bool? isMediaDelete, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the messages for everyone.
deleteMessagesForMe(String jid, String chatType, List<String> messageIds, bool? isMediaDelete, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the messages locally for the user.
deleteOfflineGroup(String groupJid) → dynamic
This method is used to delete group in offline.
deleteProfileStatus(String id, String status, bool isCurrentStatus) → Future<bool?>
Deletes a profile status.
deleteRecentChat(String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the recent chat.
deleteRecentChats(List<String> jidlist, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to delete the recent chats for the provided JIDs.
deleteUnreadMessageSeparatorOfAConversation(String jid) → Future<bool?>
This method is used to remove all unread message separators. jid: The JID of the conversation.
disconnectCall(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to disconnect the call.
disposePreview() → Future<void>
This method is used to clear the resources observers.
doesFetchingMembersListFromServedRequired(String groupJid) → Future<bool?>
This method is used to get fetch the group members list from the server is required.
downloadMedia(String mid) → dynamic
This method is used to download the media using the message ID.
editMediaCaption({required EditMessageParams editMessageParams, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to edit the media caption sent previously.
editTextMessage({required EditMessageParams editMessageParams, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to edit the text message sent previously.
enableDisableArchivedSettings(bool enable, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to enable/disable the archived settings.
enableDisableBusyStatus(bool enable, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to enable or disable the busy status for the current user.
enableDisableHideLastSeen(bool enable) → Future<bool?>
This method is used to enable or disable the last seen time for the current user.
exportChatConversationToEmail(String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to export the chat conversation to email.
forwardMessagesToMultipleUsers(List<String> messageIds, List<String> userList, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to forward the multiple messages.
getAllAvailableAudioInput() → Future<String>
This method is used to get all the available audio input.
getAllGroups([bool? server, dynamic callback(FlyResponse response)?]) → Future<void>
This method is used to get All the groups.
getAppLaunchedDetails() → Future<MirrorflyNotificationAppLaunchDetails?>
This method is used to get the app launch details.
getArchivedChatList(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the Archived chat list.
getArchivedChatsFromServer() → dynamic
This method is used to get the Archived chat list from server.
getAvailableFeatures() → Future<String>
This method is used to get available features.
getBusyStatusList() → Future<String?>
Retrieves a list of all available busy statuses.
getCallDirection() → Future<String>
This method is used to get the call direction.
getCallGroupJid() → Future<String>
This method is used to get the call group JID.
This method is used to get the ongoing call link.
getCallLogsList(int currentPage, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the call log list.
getCallType() → Future<String>
This method is used to get the call type.
getCallUsersList() → Future<String>
This method is used to get the call users list.
getCurrentAuthToken() → Future<String>
This method is used to get the AuthToken.
getCurrentCallDuration() → Future<int?>
This method is used to get current call duration only for Android.
getCurrentCameraPosition() → Future<String>
This method is used to cancel the restore started.
getDefaultNotificationUri() → Future<String?>
This method is used to get the default notification sound URI.
getDocsMessages(String jid) → Future<String?>
This method is used to get the Document messages.
getFavouriteMessages() → Future<String>
This method is used to get the favourite messages.
getGroupJid(String groupId) → Future<String?>
This method is used to get the group JID from the group ID.
getGroupMembersList(String jid, bool? server, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the group members list.
getGroupMessageDeliveredRecipients(String messageId, String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the message delivered users list in a group.
getGroupMessageDeliveredToList(String messageId, String jid) → Future<String>
This method is used to get the message delivered users list in a group.
getGroupMessageReadByList(String messageId, String jid) → Future<String>
This method is used to get the message read users list in a group.
getGroupMessageSeenRecipients(String messageId, String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the message read users list in a group.
getGroupMessageStatusCount(String messageid) → Future<int?>
This method is used to get the group message status count.
getGroupProfile(String groupJid, bool server, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the group profile.
getInvitedUsersList() → Future<List<String>>
This method is used to get the invited users list.
getIsProfileBlockedByAdmin() → Future<bool?>
This method is used to check if the user is blocked by the admin.
getJid(String username) → Future<String?>
This method is used to get the JID of the user from the username.
getJidFromPhoneNumber(String mobileNumber, String countryCode) → Future<String?>
This method is used to get JID from the phone number.
getLastNUnreadMessages(int messagesCount) → Future<String?>
This method is used to get the unread message count.
getLinkMessages(String jid) → Future<String?>
This method is used to get the Link messages.
getLocalCallLogs() → Future<String>
This method is used to get the local call log list.
getMaxCallUsersCount() → Future<int?>
This method is used to get the max call users count.
getMediaAutoDownload() → Future<bool?>
This method is used to get the media auto download settings.
getMediaMessages(String jid) → Future<String?>
This method is used to get the Media messages.
getMediaSetting(int networkType, String type) → Future<bool?>
This method is used to get the media settings.
getMeetUsername(String jid) → Future<String>
This method is used to get the Meet username.
getMembersCountOfGroup(String groupJid) → Future<int?>
This method is used to get the group members count.
getMessageOfId(String mid) → Future<String?>
This method is used to get the message using Message ID.
getMessagesOfJid(String jid) → Future<String?>
This method is used to get the message of a JID / user.
getMessageStatusOfASingleChatMessage(String messageID) → Future<String>
This method is used to get the message status of a single chat message.
getMessagesUsingIds(List<String> messageIds) → Future<String?>
This method is used to get the messages using the message ID's.
getMetaData(dynamic callback(FlyResponse response)) → dynamic
This method is used to get the metadata.
getMyBusyStatus() → Future<String>
Retrieves the current busy status of the user.
getNonChatUsers() → Future<String?>
This method is used to get the non chat users.
getNotificationSound() → Future<bool?>
This method is used to get the notification sound.
getProfileDetails(String jid) → Future<String?>
This method is used to get the user profile details.
getProfileStatusList() → Future<String?>
This method is used to get the profile status list.
getRecalledMessagesOfAConversation(String jid) → Future<String?>
Retrieves all messages that have been recalled in a conversation.
getRecentChatList(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the recent chat list.
getRecentChatListHistory({required bool firstSet, int limit = 15, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to get the recent chat history.
getRecentChatListHistoryByTopic({String? topicId, required bool firstSet, int limit = 15, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to get the recent chat list history by topic.
getRecentChatListIncludingArchived() → Future<String>
This method is used to get the recent chat list including archived.
getRecentChatOf(String jid) → Future<String>
This method is used to get the recent chat message of a user using JID.
getRegisteredUserList({required bool server}) → Future<String?>
This method is used to get the registered user list.
getRegisteredUsers(bool server, dynamic callback(FlyResponse response)) → Future<void>
This method is used to get the registered user list.
getTopics({required List<String> topicIds, dynamic callback(FlyResponse response)?}) → Future<void>
This method is used to get the topic list.
getUnreadMessageCountExceptMutedChat() → Future<int?>
This method is used to get the unread message count except muted chat.
getUnreadMessagesCount() → Future<int?>
This method is used to get the unread message count.
getUnreadMissedCallCount() → Future<int?>
This method is used to get unread missed call count.
getUnsentMessageOf(String jid) → Future<String?>
This method is used to get the Unsent message of a JID.
getUnsentMessageOfAJid(String jid) → Future<String?>
This method is used to get the Unsent message of a JID.
getUserLastSeenTime(String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get user's last seen time.
getUserList(int page, String search, MetaDataUserList? metaDataUserList, dynamic callback(FlyResponse response), {int perPageResultSize = 20}) → Future<void>
This method is used to get the user list.
getUserProfile(String jid, dynamic callback(FlyResponse response), [bool fromserver = false, bool saveasfriend = false]) → Future<void>
This method is used to get the user profile.
getUsersIBlocked(bool? server, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to get the users blocked by current user.
getUsersWhoBlockedMe([bool server = false, dynamic callback(FlyResponse response)?]) → Future<void>
Retrieves a list of users who have blocked the current user.
getValueFromManifestOrInfoPlist({String? androidManifestKey, String? iOSPlistKey}) → Future<String>
This method is used to get the value from the manifest or info.plist based on the platform.
getWebLoginDetails() → Future
This method is used to get web login details
handleReceivedMessage(Map notificationData, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to handle the FCM Push Notification Payload.
hasNextMessages() → Future<bool>
This method is used to check if there is any next messages.
hasPreviousMessages() → Future<bool>
This method is used to check if there is any previous messages.
init(ChatBuilder builder) → dynamic
Initializes the MirrorFly platform with the given builder configuration.
initializeMeet(String callLink, String userName, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to initialize the meet.
initializeMessageList({required String userJid, String? messageId, double? messageTime, bool? exclude, int limit = 25, String? topicId, MetaDataMessageList? metaDataMessageList, bool ascendingOrder = true}) → Future<bool>
This method is used to get the message list.
initializeSDK(InitializeSDKBuilder builder, dynamic callback(FlyResponse response)) → Future<void>
Initializes the SDK with the specified configuration and callback.
insertBusyStatus(String busyStatus) → Future<bool?>
This method is used to insert the busy status.
insertDefaultStatus(String status) → Future<bool?>
This method is used to insert the default status list.
insertNewProfileStatus(String status) → Future<bool?>
This method is used to insert new profile status.
inviteUsersToOngoingCall(List<String> jidList, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to invite the users to the ongoing call.
isAdmin(String userJid, String groupJID) → Future<bool?>
This method is used to check if the user is admin in a group.
isArchivedSettingsEnabled() → Future<bool?>
This method is used to check if archived settings are enabled or not.
isBusyStatusEnabled() → Future<bool>
Retrieves the current user's busy status.
isCallConnected({required dynamic callback(FlyResponse response)}) → Future<bool?>
This method is used to whether the call is connected or not
isCallConversionRequestAvailable() → Future<bool?>
This method is used to check if the call conversion request is available.
isHideLastSeenEnabled() → Future<bool?>
This method is used to check if the user last seen is enabled or not.
isLockScreen() → Future<bool>
This method is used to get screen is from locked state or not.
isMemberOfGroup(String jid, String? userJid) → Future<bool?>
This method is used to check the member is in a group.
isMuted(String jid) → Future<bool?>
This method is used to get the user is muted or not.
isOnGoingCall() → Future<bool?>
This method is used to check if the call is ongoing.
isPrivateStorageEnabledOrNot() → Future<bool>
Checks if private storage is enabled in the SDK settings.
isTrailLicence() → Future<bool?>
This method is used to check if the license is trail or not.
isUserAudioMuted([String? userJid]) → Future<bool?>
This method is used to check if the user audio is muted.
isUserUnArchived(String jid) → Future<bool?>
This method is used to check if the user is unarchived.
isUserVideoMuted([String? userJid]) → Future<bool?>
This method is used to check if the user video is muted.
joinCall(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to join the call.
leaveFromGroup(String? userJid, String groupJid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to leave the group.
loadMessages(dynamic callback(FlyResponse response)) → Future<void>
This method is used to load the messages.
loadNextMessages(dynamic callback(FlyResponse response)) → Future<void>
This method is used to load the next messages.
loadPreviousMessages(dynamic callback(FlyResponse response)) → Future<void>
This method is used to load the previous messages.
loginWebChatViaQRCode(String barcode, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to login in Web using QR Code
logoutOfChatSDK(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to logout the user from the SDK.
logoutWebUser() → Future<bool?>
This method is used to logout the user from web
makeAdmin(String groupjid, String userjid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to make the user as admin in a group.
makeGroupVideoCall(String groupJid, List<String>? jidList, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to make the group video call.
makeGroupVoiceCall(String groupJid, List<String>? jidList, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to make the group voice call.
makeVideoCall(String userJid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to make the video call.
makeVoiceCall(String userJid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to make the voice call.
markAllUnreadMissedCallsAsRead() → Future<bool?>
This method is used to mark all the unread missed calls as read.
markAsRead(String jid) → Future<bool?>
This method is used to mark the conversation as read.
markAsReadDeleteUnreadSeparator(String jid) → Future<bool?>
This method is used to delete the unread message separator.
markConversationAsRead(List<String> jidlist) → dynamic
This method is used to mark the conversation as read.
markConversationAsUnread(List<String> jidlist) → dynamic
This method is used to mark the conversation as unread.
mediaEndPoint() → Future<String?>
Retrieves the media endpoint URL.
muteAudio(bool status, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to mute the audio.
muteVideo(bool status, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to mute the video.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAudioFilePicker() → Future<String?>
This method is used to open the audio file picker only for the android platform.
recentChatPinnedCount() → Future<int?>
This method is used to get the recent chat pinned count.
refreshAndGetAuthToken(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to refresh and get the AuthToken.
registerUser(String userIdentifier, {String fcmToken = "", String userType = "", bool isForceRegister = true, List<IdentifierMetaData>? identifierMetaData, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to register the user.
removeGroupProfileImage(String jid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to remove the group profile image.
removeMemberFromGroup(String groupjid, String userjid, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to remove the user from group.
removeProfileImage(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to remove the profile image.
reportChatOrUser(String jid, String chatType, String? messageId) → Future
This method is used to report the chat or user.
reportUserOrMessages(String jid, String type, String? messageId, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to report the user or messages.
requestVideoCallSwitch() → Future<bool>
This method is used to request the video call switch.
restoreBackup({required String backupPath}) → Future<void>
This method is used to restore the backup.
revokeContactSync(dynamic callback(FlyResponse response)?) → Future<void>
Revokes the current contact sync operation.
routeAudioTo({required String routeType}) → Future<bool?>
This method is used to route the audio to different devices.
saveMediaSettings(bool photos, bool videos, bool audio, bool documents, int networkType) → dynamic
This method is used to save the media settings.
saveUnsentMessage(String jid, String message, List<String>? mentionedUsers) → dynamic
This method is used to save the unsent message.
searchConversation(String searchKey, [String? jidForSearch, bool globalSearch = true, dynamic callback(FlyResponse response)?]) → Future<void>
This method is used to search the conversation using the keyword.
selectedAudioDevice() → Future<String?>
This method is used to select the audio device.
sendAudioMessage(String jid, String filePath, bool isRecorded, String duration, String replyMessageId, {String? audioFileUrl, String? topicId}) → Future<String>
This method is used to send the audio message.
sendContactMessage(List<String> contactList, String jid, String contactName, String replyMessageId, {String? topicId}) → Future<String>
This method is used to send the contact message.
sendContactUsInfo(String title, String description, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to send contact us information.
sendDocumentMessage(String jid, String documentPath, String replyMessageId, {String? fileUrl, String? topicId}) → Future<String>
This method is used to send the document message.
sendImageMessage(String jid, String filePath, String? caption, String? replyMessageID, {String? imageFileUrl, String? topicId}) → Future<String>
This method is used to send the image message.
sendLocationMessage(String jid, double latitude, double longitude, String replyMessageId, {String? topicId}) → Future<String>
This method is used to send the location message.
sendMediaFileMessage({required FileMessage messageParams, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to send the file message.
sendMessage({required MessageParams messageParams, required dynamic callback(FlyResponse response)}) → Future<void>
This method is used to send the message with message params type.
sendTextMessage(String message, String jid, String replyMessageId, {String? topicId}) → Future<String>
This method is used to send the text message.
sendTypingGoneStatus(String toJid, String chattype) → dynamic
This method is used to remove the current user's typing status.
sendTypingStatus(String toJid, String chattype) → dynamic
This method is used to set the current user's typing status.
sendVideoMessage(String jid, String filePath, String? caption, String? replyMessageID, {String? videoFileUrl, num? videoDuration, String? thumbImageBase64, String? topicId}) → Future<String>
This method is used to send the video message.
setCallEventListener(CallEventListeners? callEventsListener) → dynamic
This listener is set to listen the call events.
setCallLinkEventListener(CallLinkEventListeners callLinkEventsListener) → void
This listener is set to listen the call link events.
setChatArchived(String jid, bool isArchived, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to set the chat is archived.
setConnectionEventListener(ConnectionEventListeners? connectionEventsListener) → dynamic
This listener is set to listen the connection events.
setDefaultNotificationSound() → Future
This method is used to set the default notification sound.
setGroupEventsListener(GroupEventListeners? groupEventsListener) → dynamic
This listener is set to listen the group events.
setLastSeenVisibility(bool enable, dynamic callback(FlyResponse response)?) → Future<void>
Sets the visibility of the last seen time for the current user.
setMediaAutoDownload(bool enable) → dynamic
This method is used to set the media auto download settings.
setMediaEncryption(bool encryption) → dynamic
This method is used to set the media encryption.
setMessageEventListener(MessageEventListeners? messageEventsListener) → dynamic
This listener is set to listen the message events.
setMuteNotification(bool enable) → dynamic
This method is used to set mute notification.
setMyBusyStatus(String busyStatus, dynamic callback(FlyResponse response)?) → Future<void>
Retrieves the current user's profile status.
setMyProfileStatus(String status, String statusId, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to set the user profile status.
setNotificationSound(bool enable) → dynamic
This method is used to set the notification sound.
setNotificationUri(String uri) → dynamic
This method is used to set the notification URI.
setNotificationVibration(bool enable) → dynamic
This method is used to set the notification vibration.
setOnGoingChatUser(String jid) → dynamic
This method is used to set the current user's chat page/ chat screen.
setProfileEventsListener(ProfileEventListeners? profileEventsListener) → dynamic
This listener is set to listen the profile events.
setRegionCode(String regionCode) → Future
This method is used to set the region code.
setTranslations({required String fileNameOrPath, String? packageName, required dynamic callback(FlyResponse response)}) → Future<void>
Sets custom translations for the MirrorFly platform.
setTypingStatusListener() → dynamic
This method is used to set typing status listener.
startBackup(bool enableEncryption) → Future<void>
This method is used to start the backup.
startVideoCapture(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to start the video capture in joined via link call.
switchCamera() → Future
This method is used to switch the camera.
syncCallLogs() → Future<bool?>
This method is used to sync the call logs.
syncContacts(bool isfirsttime, dynamic callback(FlyResponse response)?) → Future<void>
Synchronizes contacts with the server.
toString() → String
A string representation of this object.
inherited
unblockUser(String userJID, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to unblock the user.
unFavouriteAllFavouriteMessages(dynamic callback(FlyResponse response)?) → Future<void>
This method is used to un-favourite all favourite messages.
updateArchiveUnArchiveChat(String jid, bool isArchived) → Future<bool?>
This method is used to update the Archive status of the chat.
updateChatMuteStatus(String jid, bool muteStatus) → dynamic
This method is used to update the chat mute status.
updateChatMuteStatusList(List<String> jidList, bool muteStatus) → dynamic
This method is used to update the list chat mute status.
updateFavouriteStatus(String messageID, String chatUserJID, bool isFavourite, String chatType, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to update the favourite status of a message.
updateFcmToken(String firebasetoken, bool isForceUpdate, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to update the FCM Token to the MirrorFly server.
updateGroupName(String jid, String name, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to update the group profile name.
updateGroupProfileImage(String jid, String file, dynamic callback(FlyResponse response)?) → Future<void>
This method is used to update the group profile Image.
updateMediaDownloadStatus(String mediaMessageId, int progress, int downloadStatus, num dataTransferred) → dynamic
This method is used to update the media download status.
updateMediaUploadStatus(String mediaMessageId, int progress, int uploadStatus, num dataTransferred) → dynamic
This method is used to update the media upload status.
updateMetaData(List<IdentifierMetaData>? identifierMetaData, dynamic callback(FlyResponse response)?) → dynamic
This method is used to update the metadata.
updateMyProfile(String name, String? email, String? mobile, String? status, String? image, dynamic callback(FlyResponse response)) → Future<void>
This method is used to update the current user profile.
updateMyProfileImage(String image, dynamic callback(FlyResponse response)) → Future<void>
This method is used to update the profile image.
updateRecentChatPinStatus(String jid, bool pinStatus) → dynamic
This method is used to update the recent chat pin status.
uploadMedia(String messageid) → Future<bool?>
This method is used to start uploading a media file.
verifyToken(String userName, String token) → Future<String?>
This method is used to verify the Token.
override
webLoginDetailsCleared() → Future<bool?>
This method is used to clear the web login details

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlyChatFlutterPlatform
Gets the current instance of FlyChatFlutterPlatform.
getter/setter pair