FileReadResult class

A model representing the result of reading a file.

Constructors

FileReadResult({required Map<String, String>? map, required bool isSuccess, required String? errorMessage})
Creates an instance of FileReadResult.

Properties

errorMessage → String?
An optional error message if the file read failed.
final
hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
Indicates whether the file was successfully read.
final
map → Map<String, String>?
An optional contains map content from the file as a JSON.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited