ProfileDetails class

A class representing a profile detail.

Constructors

ProfileDetails({String? contactType, String? email, String? groupCreatedTime, String? image, String? imagePrivacyFlag, bool? isAdminBlocked, bool? isBlocked, bool? isBlockedMe, bool? isGroupAdmin, bool? isGroupInOfflineMode, bool? isGroupProfile, bool? isItSavedContact, bool? isMuted, bool? isSelected, String? jid, String? lastSeenPrivacyFlag, String? mobileNUmberPrivacyFlag, String? mobileNumber, String? name, String? nickName, String? status, String? thumbImage})
Constructor for the ProfileDetails class.
ProfileDetails.fromJson(Map<String, dynamic> json)
Factory method to create a ProfileDetails object from a map.
factory

Properties

contactType ↔ String?
The type of contact.
getter/setter pair
email ↔ String?
The email address of the contact.
getter/setter pair
groupCreatedTime ↔ String?
The time the group was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
The image of the contact.
getter/setter pair
imagePrivacyFlag ↔ String?
The privacy flag for the image.
getter/setter pair
isAdminBlocked ↔ bool?
Whether the contact is blocked by the admin.
getter/setter pair
isBlocked ↔ bool?
Whether the contact is blocked.
getter/setter pair
isBlockedMe ↔ bool?
Whether the contact has blocked the user.
getter/setter pair
isGroupAdmin ↔ bool?
Whether the contact is a group admin.
getter/setter pair
isGroupInOfflineMode ↔ bool?
Whether the group is in offline mode.
getter/setter pair
isGroupProfile ↔ bool?
Whether the contact is a group profile.
getter/setter pair
isItSavedContact ↔ bool?
Whether the contact is saved.
getter/setter pair
isMuted ↔ bool?
Whether the contact is muted.
getter/setter pair
isSelected ↔ bool?
Whether the contact is selected.
getter/setter pair
jid ↔ String?
The JID of the contact.
getter/setter pair
lastSeenPrivacyFlag ↔ String?
The privacy flag for the last seen time.
getter/setter pair
mobileNumber ↔ String?
The mobile number of the contact.
getter/setter pair
mobileNUmberPrivacyFlag ↔ String?
The privacy flag for the mobile number.
getter/setter pair
name ↔ String?
The name of the contact.
getter/setter pair
nickName ↔ String?
The nickname of the contact.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of the contact.
getter/setter pair
thumbImage ↔ String?
The thumbnail image of the contact.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts a ProfileDetails object into a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited