LogMessage class

LogMessage is a class that provides a static method for logging messages.

Constructors

LogMessage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

d(String tag, dynamic message) → void
Logs a debug message if debug logging is enabled and the application is in debug mode.