FlyException class

Exception class for representing Mirrorfly related errors.

Constructors

FlyException(String code, String? message, dynamic throwable)
Constructs a FlyException with the given code, message, and throwable.

Properties

code → String
Error code associated with the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Error message associated with the exception, if available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throwable → dynamic
The underlying exception or error, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a string representation of the exception.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited