FlyResponse class

Represents a response from a Mirrorfly operation.

Constructors

FlyResponse(bool isSuccess, String data, String? message, [FlyException? exception])
Constructs a FlyResponse instance.

Properties

data → String
The data returned from the operation.
final
errorDetails → dynamic
Retrieves the error message details associated with the error message.
no setter
errorMessage → String
Retrieves the error message associated with the response.
no setter
exception → FlyException?
An optional exception that occurred during the operation.
final
hasData → bool
Indicates whether the response contains data.
no setter
hasError → bool
Indicates whether the response contains error.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
Indicates whether the operation was successful.
final
message → String?
An optional message associated with the response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited