ContactChatMessage class

Represents a contact chat message.

Constructors

ContactChatMessage({required String contactName, required List<String> contactPhoneNumbers, required List<bool> isChatAppUser, required String messageId})
Constructs a ContactChatMessage instance.
ContactChatMessage.fromJson(Map<String, dynamic> json)
Converts a JSON object into a ContactChatMessage instance.
factory

Properties

contactName ↔ String
The name of the contact.
getter/setter pair
contactPhoneNumbers ↔ List<String>
The phone numbers of the contact.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isChatAppUser ↔ List<bool>
Indicates whether the contact is a chat app user.
getter/setter pair
messageId ↔ String
The ID of the message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts a ContactChatMessage instance into a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited