MeetChatMessage class

Represents a meet chat message.

Constructors

MeetChatMessage({required String? link, required String? messageId, required int? scheduledDateTime, required String? title})
Constructs a MeetChatMessage instance.
MeetChatMessage.fromJson(Map<String, dynamic> json)
Converts a JSON object into a MeetChatMessage instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
Meet link for the event
final
messageId → String?
Unique identifier for the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledDateTime → int?
Scheduled date and time of the event (in milliseconds since epoch)
final
title → String?
Title of the meeting or event
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts a MeetChatMessage instance into a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited