MirrorflyNotificationAppLaunchDetails class

Contains details on the notification that launched the application.

Constructors

MirrorflyNotificationAppLaunchDetails({String? type, dynamic value})
Constructs an instance of MirrorflyNotificationAppLaunchDetails.
MirrorflyNotificationAppLaunchDetails.fromJson(Map<String, dynamic> json)
Converts a JSON object into a MirrorflyNotificationAppLaunchDetails instance.
factory

Properties

didMediaProgressNotificationLaunchApp → bool
Indicates if the app was launched via Media Upload/Download notification.
no setter
didMissedCallNotificationLaunchApp → bool
Indicates if the app was launched via Missed Call notification.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mediaProgressChatJid → String
Contains chat jid of the Media Upload/Download notification that launched the app.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Indicates type of the notification.(MediaProgress,MissedCall)
getter/setter pair
value ↔ dynamic
Indicates value of the notification. for MissedCall it will return true or false for MediaProgress it will return chat jid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
response() → Map<String, dynamic>
Contains details of the notification that launched the app.
toJson() → Map<String, dynamic>
Contains details of the notification that launched the app.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited